@@ -111,18 +111,25 @@ class Application:
         :param in_session: Start application via command in session.
         """
 
+        kill = None
         in_session = None
+
         for key, val in kwargs.items():
             if "session" in str(key).lower():
                 in_session = val
 
+            if "kill" in str(key).lower():
+                kill = val
+
         if self.logging:
             log.info("".join((
                 f"{self.component} ",
                 f"start_via_command(self, command={command}, in_session={in_session})"
             )))
 
-        if self.is_running() and self.kill:
+        kill_override = kill if kill else self.kill
+
+        if self.is_running() and kill_override:
             self.kill_application()
 
         if in_session:
@@ -143,7 +150,7 @@ class Application:
         self.instance = self.get_root()
 
 
-    def start_via_menu(self):
+    def start_via_menu(self, kill=None):
         """
         Start application via menu.
 
@@ -155,9 +162,8 @@ class Application:
         if self.logging:
             log.info(f"{self.component} start_via_menu(self)")
 
-        gnome_version_present = run("rpm -q gnome-shell").strip("\n")
-        if ("classic" in self.session_desktop) and ("3.32" in gnome_version_present):
-            assert False, f"Application cannot be started via menu in {gnome_version_present}."
+        if "classic" in self.session_desktop:
+            assert False, f"Application cannot be started via menu in {self.session_desktop}."
 
         if not self.desktop_file_exists:
             raise Exception("".join((
@@ -165,7 +171,9 @@ class Application:
                 f"Indication of user failure!"
             )))
 
-        if self.is_running() and self.kill:
+        kill_override = kill if kill else self.kill
+
+        if self.is_running() and kill_override:
             self.kill_application()
 
         run(" ".join((
