@@ -136,8 +136,6 @@ def wait_until_in_root(context, name=None, role_name=None, description=None, m_b
             return
 
 
-#@step('Start another instance of "{application}" via "{start_via}"') # to be solved
-#@step('Start another instance of "{application}" via command:"{command}"') # to be solved
 @step('Start {application} via {start_via}') # behave-common-steps decorator
 @step('Start "{application}" via command in {session}') # behave-common-steps decorator
 @step('Start application "{application}" via "{start_via}"')
@@ -160,6 +158,26 @@ def start_application(context, application=None, start_via="command", command=No
         raise AssertionError("Only defined options are 'command' and 'menu'.")
 
 
+@step('Start another instance of "{application}" via "{start_via}"')
+@step('Start another instance of "{application}" via command "{command}"')
+@step('Start another instance of "{application}" via command in "{session}"')
+@step('Start another instance of "{application}" via command "{command}" in "{session}"')
+def start_another_instance_of_application(context, application=None, start_via="command", command=None, session=None):
+    application = get_application(context, application)
+    if start_via == "menu":
+        try:
+            application.start_via_menu(kill=False)
+        except Exception:
+            application.start_via_menu(kill=False)
+    elif start_via == "command":
+        try:
+            application.start_via_command(command=command, in_session=session, kill=False)
+        except Exception:
+            application.start_via_command(command=command, in_session=session, kill=False)
+    else:
+        raise AssertionError("Only defined options are 'command' and 'menu'.")
+
+
 @step('Close app via gnome panel') # behave-common-steps decorator
 @step('Close application "{application}" via "{close_via}"')
 def application_in_not_running(context, application=None, close_via="gnome panel"):
