@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 from os import walk, path
-from iniparse import ConfigParser
+import configparser
 
 from qecore.utility import run
 from qecore.application import Application
@@ -82,7 +82,7 @@ class Flatpak(Application):
         if not desktop_file:
             raise Exception(f"Desktop file for {self.component} not found.")
 
-        desktop_file_config = ConfigParser()
+        desktop_file_config = configparser.RawConfigParser()
         desktop_file_config.read(desktop_file)
 
         self.name = desktop_file_config.get("Desktop Entry", "name")
