@@ -4,8 +4,7 @@ from time import sleep
 import yaml
 from behave import step
 from dogtail.rawinput import pressKey, typeText
-from qecore import get_application
-from qecore import run
+from qecore.utility import get_application, run
 
 
 #####################################################################################
@@ -14,9 +13,21 @@ from qecore import run
 
 
 class Accounts:
+    """
+    **With this class all accounts are added and removed.**
+    """
+
     def __init__(self, context):
+        """
+        Initiate Accounts instance.
+
+        :type context: <behave.runner.Context>
+        :param context: Context object.
+        """
+
         self.context = context
         self.account_data = None
+
         try:
             # if its defined in environment.
             self.application = get_application(context, "gnome-control-center")
@@ -27,6 +38,10 @@ class Accounts:
 
 
     def remove_all_accounts(self):
+        """
+        Remove all accounts added via gnome-online-accounts.
+        """
+
         self.context.sandbox.detect_keyring()
         self.application.start_via_command("gnome-control-center online-accounts")
 
@@ -42,6 +57,13 @@ class Accounts:
 
 
     def remove_account(self, account_name):
+        """
+        Remove single account added via gnome-online-accounts.
+
+        :type account_name: string
+        :param account_name: Name of the account.
+        """
+
         self.context.sandbox.detect_keyring()
         self.application.start_via_command("gnome-control-center online-accounts")
 
@@ -59,6 +81,16 @@ class Accounts:
 
 
     def account_exists(self, account_name):
+        """
+        Found out if there is an account added via gnome-online-accounts.
+
+        :type account_name: string
+        :param account_name: Name of the account.
+
+        :rtype: bool
+        :return: Does the account exist or not.
+        """
+
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[0]
         existing_accounts = [x.name for x in target_panel.findChildren(lambda x:\
@@ -72,6 +104,25 @@ class Accounts:
 
 
     def add_account(self, account_id, login=None, password=None, server=None, yaml_file=None):
+        """
+        Add account to the gnome-online-accounts.
+
+        :type account_id: string
+        :param account_id: Identification fo the account.
+
+        :type login: string
+        :param login: Login name of the account user.
+
+        :type password: string
+        :param password: Password for the login.
+
+        :type server: string
+        :param server: Server.
+
+        :type yaml_file: string
+        :param yaml_file: Location of yaml file.
+        """
+
         self.context.sandbox.detect_keyring()
         self.account_data = AccountData(account_id, login=login, password=password,
                                         server=server, yaml_file=yaml_file)
@@ -110,8 +161,35 @@ class Accounts:
 
 
 class AccountData:
+    """
+    **With this class we keep and get all data about accounts.**
+    """
+
     def __init__(self, account_id, login=None, password=None,
                  server=None, yaml_data=None, yaml_file=None):
+        """
+        Account class.
+
+        :type account_id: string
+        :param account_id: Identification fo the account.
+
+        :type login: string
+        :param login: Login name of the account user.
+
+        :type password: string
+        :param password: Password for the login.
+
+        :type server: string
+        :param server: Server.
+
+        :type yaml_file: string
+        :param yaml_file: Location of yaml file.
+
+        .. note::
+
+            This class is called by :func:`online_accounts.Accounts.add_account`.
+        """
+
         self.account_id = account_id
 
         self.name = account_id
@@ -135,6 +213,13 @@ class AccountData:
 
 
     def get_account_data(self, yaml_file="online_accounts.yaml"):
+        """
+        Load yaml data to the class attribute.
+
+        :type yaml_file: string
+        :param yaml_file: Location of the yaml file.
+        """
+
         assert os.path.isfile(yaml_file),\
             "\n".join((
                 "\n\nFor online accounts you need to supply the credentials in yaml format.",
@@ -155,6 +240,11 @@ class AccountData:
 
 
     def parse_account_data(self):
+        """
+        Parse the data from the yaml data.
+        Retrieves name, login, password, server.
+        """
+
         try:
             self.name = self.yaml_data[self.account_id]["name"]
         except Exception:
@@ -182,12 +272,32 @@ class AccountData:
 
 
 def wait_until_progress_bar_dissapears_in(account_login_dialog):
+    """
+    Waiting until the progress bar from the gnome-online-accounts widget disappears.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: Node in which the progress bar is being searched in.
+    """
+
     progress_bar = account_login_dialog.findChildren(lambda x: x.roleName == "progress bar")
     while progress_bar and progress_bar[0].showing:
         sleep(0.2)
 
 
 def add_google_account(context, data, account_login_dialog):
+    """
+    Adding a Google account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -219,6 +329,19 @@ def add_google_account(context, data, account_login_dialog):
 
 
 def add_nextcloud_account(context, data, account_login_dialog):
+    """
+    Adding a Nextcloud account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     server_entry = account_login_dialog.findChildren(lambda x: x.roleName == "text")[1]
     server_entry.text = data.server
 
@@ -234,6 +357,19 @@ def add_nextcloud_account(context, data, account_login_dialog):
 
 
 def add_facebook_account(context, data, account_login_dialog):
+    """
+    Adding a Facebook account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -253,6 +389,19 @@ def add_facebook_account(context, data, account_login_dialog):
 
 
 def add_microsoft_account(context, data, account_login_dialog):
+    """
+    Adding a Microsoft account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -273,6 +422,19 @@ def add_microsoft_account(context, data, account_login_dialog):
 
 
 def add_flickr_account(context, data, account_login_dialog):
+    """
+    Adding a Flickr account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -306,6 +468,19 @@ def add_flickr_account(context, data, account_login_dialog):
 
 
 def add_pocket_account(context, data, account_login_dialog):
+    """
+    Adding a Pocket account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     pressKey("PageDown")
     pressKey("PageDown")
@@ -358,6 +533,19 @@ def add_pocket_account(context, data, account_login_dialog):
 
 
 def add_foursquare_account(context, data, account_login_dialog):
+    """
+    Adding a FourSquare account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -376,6 +564,19 @@ def add_foursquare_account(context, data, account_login_dialog):
 
 
 def add_microsoft_exchange_account(context, data, account_login_dialog):
+    """
+    Adding a Microsoft Exchange account to the gnome-online-accounts.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object.
+
+    :type data: AccountData
+    :param data: Data needed: account_id, login, password, server.
+
+    :type account_login_dialog: Node
+    :param account_login_dialog: gnome-online-accounts dialog for given account.
+    """
+
     run("sudo sed -i 's/DEFAULT/LEGACY/g' /etc/crypto-policies/config")
     run("sudo update-crypto-policies")
 
@@ -409,6 +610,14 @@ def add_microsoft_exchange_account(context, data, account_login_dialog):
 @step('Add "{account_name}" account from file "{yaml_file}"')
 @step('Add "{account_name}" account with login "{login}" and password "{password}"')
 def add_account(context, account_name, login=None, password=None, yaml_file=None):
+    """
+    Function with behave step decorators::
+
+        Add "{account_name}" account
+        Add "{account_name}" account from file "{yaml_file}"
+        Add "{account_name}" account with login "{login}" and password "{password}"
+    """
+
     accounts = Accounts(context)
     try:
         accounts.add_account(account_name, login=login, password=password, yaml_file=yaml_file)
@@ -419,6 +628,12 @@ def add_account(context, account_name, login=None, password=None, yaml_file=None
 
 @step('Remove all accounts')
 def remove_accounts(context):
+    """
+    Function with behave step decorator::
+
+        Remove all accounts
+    """
+
     accounts = Accounts(context)
     try:
         accounts.remove_all_accounts()
